STOP_WORDS = {
    "a",
    "a's",
    "abbia",
    "abbiamo",
    "abbiano",
    "abbiate",
    "able",
    "about",
    "above",
    "according",
    "accordingly",
    "across",
    "actually",
    "ad",
    "after",
    "afterwards",
    "again",
    "against",
    "agl",
    "agli",
    "ai",
    "aie",
    "aient",
    "aies",
    "ain't",
    "ait",
    "al",
    "algo",
    "algunas",
    "algunos",
    "all",
    "alla",
    "alle",
    "allo",
    "allow",
    "allows",
    "almost",
    "alone",
    "along",
    "already",
    "also",
    "although",
    "always",
    "am",
    "among",
    "amongst",
    "an",
    "anche",
    "and",
    "another",
    "ante",
    "antes",
    "any",
    "anybody",
    "anyhow",
    "anyone",
    "anything",
    "anyway",
    "anyways",
    "anywhere",
    "ao",
    "aos",
    "apart",
    "appear",
    "appreciate",
    "appropriate",
    "aquela",
    "aquelas",
    "aquele",
    "aqueles",
    "aquilo",
    "are",
    "aren't",
    "around",
    "as",
    "aside",
    "ask",
    "asking",
    "associated",
    "at",
    "até",
    "au",
    "aura",
    "aurai",
    "auraient",
    "aurais",
    "aurait",
    "auras",
    "aurez",
    "auriez",
    "aurions",
    "aurons",
    "auront",
    "aux",
    "avaient",
    "available",
    "avais",
    "avait",
    "avec",
    "avemmo",
    "avendo",
    "avesse",
    "avessero",
    "avessi",
    "avessimo",
    "aveste",
    "avesti",
    "avete",
    "aveva",
    "avevamo",
    "avevano",
    "avevate",
    "avevi",
    "avevo",
    "avez",
    "aviez",
    "avions",
    "avons",
    "avrai",
    "avranno",
    "avrebbe",
    "avrebbero",
    "avrei",
    "avremmo",
    "avremo",
    "avreste",
    "avresti",
    "avrete",
    "avrà",
    "avrò",
    "avuta",
    "avute",
    "avuti",
    "avuto",
    "away",
    "awfully",
    "ayant",
    "ayez",
    "ayons",
    "b",
    "be",
    "became",
    "because",
    "become",
    "becomes",
    "becoming",
    "been",
    "before",
    "beforehand",
    "behind",
    "being",
    "believe",
    "below",
    "beside",
    "besides",
    "best",
    "better",
    "between",
    "beyond",
    "both",
    "brief",
    "but",
    "by",
    "c",
    "c'mon",
    "c's",
    "came",
    "can",
    "can't",
    "cannot",
    "cant",
    "cause",
    "causes",
    "ce",
    "ceci",
    "cela",
    "celà",
    "certain",
    "certainly",
    "ces",
    "cet",
    "cette",
    "changes",
    "che",
    "chi",
    "ci",
    "clearly",
    "co",
    "coi",
    "col",
    "com",
    "come",
    "comes",
    "como",
    "con",
    "concerning",
    "consequently",
    "consider",
    "considering",
    "contain",
    "containing",
    "contains",
    "contra",
    "contro",
    "corresponding",
    "could",
    "couldn't",
    "course",
    "cual",
    "cuando",
    "cui",
    "currently",
    "d",
    "da",
    "dagl",
    "dagli",
    "dai",
    "dal",
    "dall",
    "dalla",
    "dalle",
    "dallo",
    "dans",
    "das",
    "de",
    "definitely",
    "degl",
    "degli",
    "dei",
    "del",
    "dela",
    "delas",
    "dele",
    "deles",
    "dell",
    "della",
    "delle",
    "dello",
    "depois",
    "des",
    "described",
    "desde",
    "despite",
    "di",
    "did",
    "didn't",
    "different",
    "do",
    "does",
    "doesn't",
    "doing",
    "don't",
    "donde",
    "done",
    "dos",
    "dov",
    "dove",
    "down",
    "downwards",
    "du",
    "durante",
    "during",
    "e",
    "each",
    "ebbe",
    "ebbero",
    "ebbi",
    "ed",
    "edu",
    "eg",
    "eight",
    "either",
    "el",
    "ela",
    "elas",
    "ele",
    "eles",
    "ella",
    "ellas",
    "elle",
    "ellos",
    "else",
    "elsewhere",
    "em",
    "en",
    "enough",
    "entirely",
    "entre",
    "era",
    "erais",
    "eram",
    "eran",
    "erano",
    "eras",
    "eravamo",
    "eravate",
    "eres",
    "eri",
    "ero",
    "es",
    "esa",
    "esas",
    "ese",
    "eso",
    "esos",
    "especially",
    "essa",
    "essas",
    "esse",
    "essendo",
    "esses",
    "est",
    "esta",
    "estaba",
    "estabais",
    "estaban",
    "estabas",
    "estada",
    "estadas",
    "estado",
    "estados",
    "estamos",
    "estando",
    "estar",
    "estaremos",
    "estará",
    "estarán",
    "estarás",
    "estaré",
    "estaréis",
    "estaría",
    "estaríais",
    "estaríamos",
    "estarían",
    "estarías",
    "estas",
    "estava",
    "estavam",
    "este",
    "esteja",
    "estejam",
    "estejamos",
    "estemos",
    "estes",
    "esteve",
    "estive",
    "estivemos",
    "estiver",
    "estivera",
    "estiveram",
    "estiverem",
    "estivermos",
    "estivesse",
    "estivessem",
    "estivéramos",
    "estivéssemos",
    "esto",
    "estos",
    "estou",
    "estoy",
    "estuve",
    "estuviera",
    "estuvierais",
    "estuvieran",
    "estuvieras",
    "estuvieron",
    "estuviese",
    "estuvieseis",
    "estuviesen",
    "estuvieses",
    "estuvimos",
    "estuviste",
    "estuvisteis",
    "estuviéramos",
    "estuviésemos",
    "estuvo",
    "está",
    "estábamos",
    "estáis",
    "están",
    "estás",
    "estávamos",
    "estão",
    "esté",
    "estéis",
    "estén",
    "estés",
    "et",
    "etc",
    "eu",
    "eue",
    "eues",
    "eurent",
    "eus",
    "eusse",
    "eussent",
    "eusses",
    "eussiez",
    "eussions",
    "eut",
    "eux",
    "even",
    "ever",
    "every",
    "everybody",
    "everyone",
    "everything",
    "everywhere",
    "ex",
    "exactly",
    "example",
    "except",
    "eûmes",
    "eût",
    "eûtes",
    "f",
    "faccia",
    "facciamo",
    "facciano",
    "facciate",
    "faccio",
    "facemmo",
    "facendo",
    "facesse",
    "facessero",
    "facessi",
    "facessimo",
    "faceste",
    "facesti",
    "faceva",
    "facevamo",
    "facevano",
    "facevate",
    "facevi",
    "facevo",
    "fai",
    "fanno",
    "far",
    "farai",
    "faranno",
    "farebbe",
    "farebbero",
    "farei",
    "faremmo",
    "faremo",
    "fareste",
    "faresti",
    "farete",
    "farà",
    "farò",
    "fece",
    "fecero",
    "feci",
    "few",
    "fifth",
    "first",
    "five",
    "foi",
    "followed",
    "following",
    "follows",
    "fomos",
    "for",
    "fora",
    "foram",
    "forem",
    "former",
    "formerly",
    "formos",
    "forth",
    "fosse",
    "fossem",
    "fossero",
    "fossi",
    "fossimo",
    "foste",
    "fosti",
    "four",
    "from",
    "fu",
    "fue",
    "fuera",
    "fuerais",
    "fueran",
    "fueras",
    "fueron",
    "fuese",
    "fueseis",
    "fuesen",
    "fueses",
    "fui",
    "fuimos",
    "fuiste",
    "fuisteis",
    "fummo",
    "furent",
    "furono",
    "further",
    "furthermore",
    "fus",
    "fusse",
    "fussent",
    "fusses",
    "fussiez",
    "fussions",
    "fut",
    "fuéramos",
    "fuésemos",
    "fôramos",
    "fôssemos",
    "fûmes",
    "fût",
    "fûtes",
    "g",
    "get",
    "gets",
    "getting",
    "given",
    "gives",
    "gli",
    "go",
    "goes",
    "going",
    "gone",
    "got",
    "gotten",
    "greetings",
    "h",
    "ha",
    "haber",
    "habida",
    "habidas",
    "habido",
    "habidos",
    "habiendo",
    "habremos",
    "habrá",
    "habrán",
    "habrás",
    "habré",
    "habréis",
    "habría",
    "habríais",
    "habríamos",
    "habrían",
    "habrías",
    "habéis",
    "había",
    "habíais",
    "habíamos",
    "habían",
    "habías",
    "had",
    "hadn't",
    "hai",
    "haja",
    "hajam",
    "hajamos",
    "han",
    "hanno",
    "happens",
    "hardly",
    "has",
    "hasn't",
    "hasta",
    "have",
    "havemos",
    "haven't",
    "havia",
    "having",
    "hay",
    "haya",
    "hayamos",
    "hayan",
    "hayas",
    "hayáis",
    "he",
    "he's",
    "hei",
    "hello",
    "help",
    "hemos",
    "hence",
    "her",
    "here",
    "here's",
    "hereafter",
    "hereby",
    "herein",
    "hereupon",
    "hers",
    "herself",
    "hi",
    "him",
    "himself",
    "his",
    "hither",
    "ho",
    "hopefully",
    "houve",
    "houvemos",
    "houver",
    "houvera",
    "houveram",
    "houverei",
    "houverem",
    "houveremos",
    "houveria",
    "houveriam",
    "houvermos",
    "houverá",
    "houverão",
    "houveríamos",
    "houvesse",
    "houvessem",
    "houvéramos",
    "houvéssemos",
    "how",
    "howbeit",
    "however",
    "hube",
    "hubiera",
    "hubierais",
    "hubieran",
    "hubieras",
    "hubieron",
    "hubiese",
    "hubieseis",
    "hubiesen",
    "hubieses",
    "hubimos",
    "hubiste",
    "hubisteis",
    "hubiéramos",
    "hubiésemos",
    "hubo",
    "há",
    "hão",
    "i",
    "i'd",
    "i'll",
    "i'm",
    "i've",
    "ici",
    "ie",
    "if",
    "ignored",
    "il",
    "ils",
    "immediate",
    "in",
    "inasmuch",
    "inc",
    "indeed",
    "indicate",
    "indicated",
    "indicates",
    "inner",
    "insofar",
    "instead",
    "into",
    "inward",
    "io",
    "is",
    "isn't",
    "isso",
    "isto",
    "it",
    "it'd",
    "it'll",
    "it's",
    "its",
    "itself",
    "j",
    "je",
    "just",
    "já",
    "k",
    "keep",
    "keeps",
    "kept",
    "know",
    "known",
    "knows",
    "l",
    "la",
    "las",
    "last",
    "lately",
    "later",
    "latter",
    "latterly",
    "le",
    "least",
    "lei",
    "les",
    "less",
    "lest",
    "let",
    "let's",
    "leur",
    "leurs",
    "lhe",
    "lhes",
    "li",
    "like",
    "liked",
    "likely",
    "little",
    "lo",
    "look",
    "looking",
    "looks",
    "loro",
    "los",
    "ltd",
    "lui",
    "m",
    "ma",
    "mainly",
    "mais",
    "many",
    "mas",
    "may",
    "maybe",
    "me",
    "mean",
    "meanwhile",
    "merely",
    "mes",
    "mesmo",
    "meu",
    "meus",
    "mi",
    "mia",
    "mie",
    "miei",
    "might",
    "minha",
    "minhas",
    "mio",
    "mis",
    "moi",
    "mon",
    "more",
    "moreover",
    "most",
    "mostly",
    "much",
    "mucho",
    "muchos",
    "muito",
    "must",
    "muy",
    "my",
    "myself",
    "más",
    "même",
    "mí",
    "mía",
    "mías",
    "mío",
    "míos",
    "n",
    "na",
    "nada",
    "name",
    "namely",
    "nas",
    "nd",
    "ne",
    "near",
    "nearly",
    "necessary",
    "need",
    "needs",
    "negl",
    "negli",
    "nei",
    "neither",
    "nel",
    "nell",
    "nella",
    "nelle",
    "nello",
    "nem",
    "never",
    "nevertheless",
    "new",
    "next",
    "ni",
    "nine",
    "no",
    "nobody",
    "noi",
    "non",
    "none",
    "noone",
    "nor",
    "normally",
    "nos",
    "nosotras",
    "nosotros",
    "nossa",
    "nossas",
    "nosso",
    "nossos",
    "nostra",
    "nostre",
    "nostri",
    "nostro",
    "not",
    "nothing",
    "notre",
    "nous",
    "novel",
    "now",
    "nowhere",
    "nuestra",
    "nuestras",
    "nuestro",
    "nuestros",
    "num",
    "numa",
    "não",
    "nós",
    "o",
    "obviously",
    "of",
    "off",
    "often",
    "oh",
    "ok",
    "okay",
    "old",
    "on",
    "once",
    "one",
    "ones",
    "only",
    "ont",
    "onto",
    "or",
    "os",
    "other",
    "others",
    "otherwise",
    "otra",
    "otras",
    "otro",
    "otros",
    "ou",
    "ought",
    "our",
    "ours",
    "ourselves",
    "out",
    "outside",
    "over",
    "overall",
    "own",
    "p",
    "par",
    "para",
    "particular",
    "particularly",
    "pas",
    "pela",
    "pelas",
    "pelo",
    "pelos",
    "per",
    "perché",
    "perhaps",
    "pero",
    "più",
    "placed",
    "please",
    "plus",
    "poco",
    "por",
    "porque",
    "possible",
    "pour",
    "presumably",
    "probably",
    "provides",
    "q",
    "qu",
    "qual",
    "quale",
    "quando",
    "quanta",
    "quante",
    "quanti",
    "quanto",
    "que",
    "quel",
    "quella",
    "quelle",
    "quelles",
    "quelli",
    "quello",
    "quels",
    "quem",
    "questa",
    "queste",
    "questi",
    "questo",
    "qui",
    "quien",
    "quienes",
    "quite",
    "qué",
    "qv",
    "r",
    "rather",
    "rd",
    "re",
    "really",
    "reasonably",
    "regarding",
    "regardless",
    "regards",
    "relatively",
    "respectively",
    "right",
    "s",
    "sa",
    "said",
    "same",
    "sans",
    "sarai",
    "saranno",
    "sarebbe",
    "sarebbero",
    "sarei",
    "saremmo",
    "saremo",
    "sareste",
    "saresti",
    "sarete",
    "sarà",
    "sarò",
    "saw",
    "say",
    "saying",
    "says",
    "se",
    "sea",
    "seamos",
    "sean",
    "seas",
    "second",
    "secondly",
    "see",
    "seeing",
    "seem",
    "seemed",
    "seeming",
    "seems",
    "seen",
    "sei",
    "seja",
    "sejam",
    "sejamos",
    "self",
    "selves",
    "sem",
    "sensible",
    "sent",
    "ser",
    "sera",
    "serai",
    "seraient",
    "serais",
    "serait",
    "seras",
    "serei",
    "seremos",
    "serez",
    "seria",
    "seriam",
    "seriez",
    "serions",
    "serious",
    "seriously",
    "serons",
    "seront",
    "será",
    "serán",
    "serás",
    "serão",
    "seré",
    "seréis",
    "sería",
    "seríais",
    "seríamos",
    "serían",
    "serías",
    "ses",
    "seu",
    "seus",
    "seven",
    "several",
    "seáis",
    "shall",
    "she",
    "should",
    "shouldn't",
    "si",
    "sia",
    "siamo",
    "siano",
    "siate",
    "sido",
    "siendo",
    "siete",
    "sin",
    "since",
    "six",
    "so",
    "sobre",
    "soi",
    "soient",
    "sois",
    "soit",
    "some",
    "somebody",
    "somehow",
    "someone",
    "something",
    "sometime",
    "sometimes",
    "somewhat",
    "somewhere",
    "sommes",
    "somos",
    "son",
    "sono",
    "sont",
    "soon",
    "sorry",
    "sou",
    "soy",
    "soyez",
    "soyons",
    "specified",
    "specify",
    "specifying",
    "sta",
    "stai",
    "stando",
    "stanno",
    "starai",
    "staranno",
    "starebbe",
    "starebbero",
    "starei",
    "staremmo",
    "staremo",
    "stareste",
    "staresti",
    "starete",
    "starà",
    "starò",
    "stava",
    "stavamo",
    "stavano",
    "stavate",
    "stavi",
    "stavo",
    "stemmo",
    "stesse",
    "stessero",
    "stessi",
    "stessimo",
    "steste",
    "stesti",
    "stette",
    "stettero",
    "stetti",
    "stia",
    "stiamo",
    "stiano",
    "stiate",
    "still",
    "sto",
    "su",
    "sua",
    "suas",
    "sub",
    "such",
    "sue",
    "sugl",
    "sugli",
    "sui",
    "suis",
    "sul",
    "sull",
    "sulla",
    "sulle",
    "sullo",
    "suo",
    "suoi",
    "sup",
    "sur",
    "sure",
    "sus",
    "suya",
    "suyas",
    "suyo",
    "suyos",
    "são",
    "sí",
    "só",
    "t",
    "t's",
    "ta",
    "take",
    "taken",
    "también",
    "também",
    "tanto",
    "te",
    "tell",
    "tem",
    "temos",
    "tendremos",
    "tendrá",
    "tendrán",
    "tendrás",
    "tendré",
    "tendréis",
    "tendría",
    "tendríais",
    "tendríamos",
    "tendrían",
    "tendrías",
    "tends",
    "tened",
    "tenemos",
    "tenga",
    "tengamos",
    "tengan",
    "tengas",
    "tengo",
    "tengáis",
    "tenha",
    "tenham",
    "tenhamos",
    "tenho",
    "tenida",
    "tenidas",
    "tenido",
    "tenidos",
    "teniendo",
    "tenéis",
    "tenía",
    "teníais",
    "teníamos",
    "tenían",
    "tenías",
    "ter",
    "terei",
    "teremos",
    "teria",
    "teriam",
    "terá",
    "terão",
    "teríamos",
    "tes",
    "teu",
    "teus",
    "teve",
    "th",
    "than",
    "thank",
    "thanks",
    "thanx",
    "that",
    "that's",
    "thats",
    "the",
    "their",
    "theirs",
    "them",
    "themselves",
    "then",
    "thence",
    "there",
    "there's",
    "thereafter",
    "thereby",
    "therefore",
    "therein",
    "theres",
    "thereupon",
    "these",
    "they",
    "they'd",
    "they'll",
    "they're",
    "they've",
    "think",
    "third",
    "this",
    "thorough",
    "thoroughly",
    "those",
    "though",
    "three",
    "through",
    "throughout",
    "thru",
    "thus",
    "ti",
    "tiene",
    "tienen",
    "tienes",
    "tinha",
    "tinham",
    "tive",
    "tivemos",
    "tiver",
    "tivera",
    "tiveram",
    "tiverem",
    "tivermos",
    "tivesse",
    "tivessem",
    "tivéramos",
    "tivéssemos",
    "to",
    "todo",
    "todos",
    "together",
    "toi",
    "ton",
    "too",
    "took",
    "toward",
    "towards",
    "tra",
    "tried",
    "tries",
    "truly",
    "try",
    "trying",
    "tu",
    "tua",
    "tuas",
    "tue",
    "tuo",
    "tuoi",
    "tus",
    "tutti",
    "tutto",
    "tuve",
    "tuviera",
    "tuvierais",
    "tuvieran",
    "tuvieras",
    "tuvieron",
    "tuviese",
    "tuvieseis",
    "tuviesen",
    "tuvieses",
    "tuvimos",
    "tuviste",
    "tuvisteis",
    "tuviéramos",
    "tuviésemos",
    "tuvo",
    "tuya",
    "tuyas",
    "tuyo",
    "tuyos",
    "twice",
    "two",
    "tém",
    "têm",
    "tínhamos",
    "tú",
    "u",
    "um",
    "uma",
    "un",
    "una",
    "under",
    "une",
    "unfortunately",
    "unless",
    "unlikely",
    "uno",
    "unos",
    "until",
    "unto",
    "up",
    "upon",
    "us",
    "use",
    "used",
    "useful",
    "uses",
    "using",
    "usually",
    "uucp",
    "v",
    "value",
    "various",
    "very",
    "vi",
    "via",
    "viz",
    "você",
    "vocês",
    "voi",
    "vos",
    "vosotras",
    "vosotros",
    "vostra",
    "vostre",
    "vostri",
    "vostro",
    "votre",
    "vous",
    "vs",
    "vuestra",
    "vuestras",
    "vuestro",
    "vuestros",
    "w",
    "want",
    "wants",
    "was",
    "wasn't",
    "way",
    "we",
    "we'd",
    "we'll",
    "we're",
    "we've",
    "welcome",
    "well",
    "went",
    "were",
    "weren't",
    "what",
    "what's",
    "whatever",
    "when",
    "whence",
    "whenever",
    "where",
    "where's",
    "whereafter",
    "whereas",
    "whereby",
    "wherein",
    "whereupon",
    "wherever",
    "whether",
    "which",
    "while",
    "whither",
    "who",
    "who's",
    "whoever",
    "whole",
    "whom",
    "whose",
    "why",
    "will",
    "willing",
    "wish",
    "with",
    "within",
    "without",
    "won't",
    "wonder",
    "would",
    "wouldn't",
    "x",
    "y",
    "ya",
    "yes",
    "yet",
    "yo",
    "you",
    "you'd",
    "you'll",
    "you're",
    "you've",
    "your",
    "yours",
    "yourself",
    "yourselves",
    "z",
    "zero",
    "à",
    "às",
    "è",
    "é",
    "él",
    "éramos",
    "étaient",
    "étais",
    "était",
    "étant",
    "étiez",
    "étions",
    "été",
    "étée",
    "étées",
    "étés",
    "êtes",
}
